function [fingercode Fmasked] = fingercode_creation(imOriginal, Gfilt, core, maskSize, dia)

% Funkce pro vypocet FingerCode priznaku z otisku prstu.
%
% [fingercode Fmasked] = fingercode_creation(imOriginal, Gfilt, core, maskSize, dia)
%
%   vstupy: imOriginal - vstupni obrazek otisku
%           Gfilt - banka Gaborovych filtru
%           core - [x;y] souradnice jadra otisku
%           maskSize - velikost bloku pri blokovem zpracovani (deafult 16)
%           dia - velikost [vnejsi vnitrni] polomer masky
%
%   vystupy: fingercode - priznakovy vektor pro obrazek
%            Fmasked - ilustracni blokovy obrazek s vyrizlym mezikruzim

if ~exist('maskSize', 'var'), maskSize = []; end
if isempty(maskSize), maskSize = 16; end
if ~exist('dia', 'var'), dia = []; end
if isempty(dia), dia = [6 2]; end

imOriginal = blkpad(imOriginal, maskSize);
if (isempty(core))
    fingercode = 0;
else
 fingercode = [];
 for k = 1:8
    g = Gfilt{k};
    I2 = imfilter(imOriginal, g);
    I3 = zeros(size(imOriginal, 1)/maskSize, size(imOriginal,2)/maskSize);
    x = 1;

    for i = 1:maskSize:size(imOriginal, 1)
        y = 1;
        for j = 1:maskSize:size(imOriginal,2)
            r = reshape(I2(i:i+maskSize-1, j:j+maskSize-1), [1 maskSize*maskSize]);
            value = abs(mean(r) - std(r))*maskSize;
            I3(x,y) = value;
            y = y+1;
        end
        x = x+1;
    end
    cY = round(core(1,1)/maskSize);
    cX = round(core(1,2)/maskSize);
    for i = 1:size(I3, 1)
        for j = 1:size(I3, 2)
            d = sqrt((cX - j)^2 + (cY - i)^2);
            if(d<min(dia) || d>max(dia))
                I3(i,j) = 0;
            end
        end
    end
    fingercode = [fingercode reshape(I3(I3 ~= 0), 1, [])];
 end
 figure(45)
 imshow(I3), hold on
 plot(cX, cY), hold off;
end

% DOPLNIT

